astcheck |version|
==================

astcheck is a module for checking a Python Abstract Syntax Tree against a
template. This is useful for testing code that automatically generates or
modifies Python code.

For more details about the structure of ASTs, see my documentation project,
`Green Tree Snakes <http://greentreesnakes.readthedocs.org/en/latest/index.html>`_.

.. toctree::
   :maxdepth: 2

   checking
   templateutils
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

